@@ -82,7 +82,7 @@ CActionLabel::~CActionLabel()
         for(int i=0; i<constNumIcons; ++i)
         {
             delete theIcons[i];
-            theIcons[i]=NULL;
+            theIcons[i]=nullptr;
         }
 }
 
